Skip to main contentCrate gearbox_rs_postgres
Source - query
- Types and traits for the
query family of functions and macros.
- query
- Statically checked SQL query with
println!() style syntax. - query_scalar
- A variant of
query! which expects a single column from the query and evaluates to an
instance of QueryScalar.
- PgClient
- PostgreSQL client Cog that manages a map of connection pools keyed by schema name.
- PgConfig
- Top-level PostgreSQL configuration, loaded from the
[postgres] section of config.toml. - PgRow
- Implementation of
Row for PostgreSQL. - SchemaConfig
- Configuration for a single PostgreSQL schema, including its name and migration path.
- PgError
- PgEntity
- Trait that defines entity metadata for database operations.
- PgRepository
- Repository trait providing CRUD operations for entities on PgClient.
- Row
- Represents a single row from the database.
- query
- Execute a single SQL query as a prepared statement (transparently cached).
- query_scalar
- Execute a single SQL query as a prepared statement (transparently cached) and extract the first
column of each row.